﻿//=============================================================================
// TN_LightSaveData_Map.js
//=============================================================================
// Released under the MIT license
// http://opensource.org/licenses/mit-license.php
/*:ja
 * @plugindesc マップ上のイベントの情報をセーブ対象から外して、セーブファイルを軽量化します。
 * @author terunon（エイリアスエイク）
 * @version 1.00
 *
 * @help
 * イベントの情報をセーブ対象から外してセーブ容量を減らします。
 * サーバーセーブ容量に限界があるRPGアツマール環境で有効です。
 *
 * ツクールではセーブ時、マップ内の全イベントの情報をセーブするため
 * イベント数の多いマップでセーブするとセーブ容量が大きく増えますが、
 * 本プラグインを入れるとイベント数がどれだけ増えてもセーブ容量が増えなくなります。
 *
 * 性質上、ゲームをロードするとイベント位置が初期位置に戻ります。
 *（プロジェクトを更新後に更新前のセーブを読み込んだときと同じ動作）
 *
 * 例えば、岩を押す等のパズルギミックの最中にセーブ＆ロードが挟まると
 * 勝手に岩の位置が初期化するのでご注意ください。
 * （なお、この仕様はプロジェクトとセーブデータの版が違うと
 * 　本プラグインとは無関係に発生するので、こういったパズルエリアでは
 * 　本来セーブを禁止する等の対策を取るべきです。）
 *
 * ※本プラグインの導入や廃止によって既存セーブファイルが読み込めなくなることはありません。
 *
 * -------------------------------------------------------------
 * 商用非商用・年齢制限問わず利用できます。
 * クレジットに「terunon（エイリアスエイク）」の記載をお願いします。
 * ※ 制作スタッフっぽく見える記載方法はご遠慮くださいね！
 */

//グローバル変数
var TN_gameMap = []; 

(function() {
'use strict';

//イベントをセーブから除外
var TN_Game_System_onBeforeSave      = Game_System.prototype.onBeforeSave;
Game_System.prototype.onBeforeSave = function() {
    TN_Game_System_onBeforeSave.apply(this, arguments);
    TN_gameMap = $gameMap._events;
    $gameMap._events = [];
};

//除外したイベントデータを復帰
var TN_Scene_Save_onSavefileOk = Scene_Save.prototype.onSavefileOk;
Scene_Save.prototype.onSavefileOk = function() {
    TN_Scene_Save_onSavefileOk.call(this);
    $gameMap._events = TN_gameMap;
};

//ロード時マップを再生成
Scene_Load.prototype.reloadMapIfUpdated = function() {
    $gamePlayer.reserveTransfer($gameMap.mapId(), $gamePlayer.x, $gamePlayer.y);
    $gamePlayer.requestMapReload();
};


})();

